@@ -3,7 +3,8 @@ package Getopt::Complete::Args;
 use strict;
 use warnings;
 
-our $VERSION = $Getopt::Complete::VERSION;
+use version;
+our $VERSION = qv('0.10');
 
 use Getopt::Long;
 use Scalar::Util;
@@ -122,25 +123,16 @@ sub _init {
         if (!$retval and @errors == 0) {
             push @errors, "unknown error processing arguments!";
         }
-        if ($ENV{COMP_LINE}) {
-            # we want to allow unknown option if the user puts them in, we just
-            # didn't help complete it
-            @errors = grep { $_ !~ /^Unknown option:/ } @errors;
-        }
     };
 
     if (@ARGV) {
-        if ($self->options->has_option('<>')) {
+        if ($self->options->completion_handler('<>')) {
             my $a = $values{'<>'} ||= [];
             push @$a, @ARGV;
         }
         else {
-            # in order to allow bare-args we only block unexpected arguments
-            # for commands with sub-commands
-            if ( $self->sub_commands ) {
-                for my $arg (@ARGV) {
-                    push @errors, "unexpected sub-command: $arg";
-                }
+            for my $arg (@ARGV) {
+                push @errors, "unexpected unnamed arguments: $arg";
             }
         }
     }
@@ -230,7 +222,7 @@ sub resolve_possible_completions {
 
     my @possibilities;
 
-    my ($dashes,$resolve_values_for_option_name) = ($previous =~ /^(-{1,2})(.*)/); 
+    my ($dashes,$resolve_values_for_option_name) = ($previous =~ /^(--)(.*)/); 
     my $is_option_name = 0;
     if (not length $previous) {
         # no specific option is before this: a sub-command, a bare argument, or an option name
@@ -278,11 +270,11 @@ sub resolve_possible_completions {
                 # already showing the complete list
                 push @possibilities, "--no-\t";
             }
-            if ($current =~ /-{1,2}(.+?)=(.*)/) {
+            if ($current =~ /--(.+?)=(.*)/) {
                 # using the --key=value syntax..
                 my ($option,$value) = ($1,$2);
                 @possibilities = $self->reduce_possibilities_for_current_word('--' . $option, @possibilities);
-                if (!@possibilities || @possibilities == 1 and length($current) >= $possibilities[0]) {
+                if (@possibilities == 1 and length($current) >= $possibilities[0]) {
                     # the key portion is complete
                     # continue below as though were were doing a regular value completion
                     $resolve_values_for_option_name = $option;
@@ -309,12 +301,9 @@ sub resolve_possible_completions {
             }
             @possibilities = @$handler;
         }
-        elsif ($resolve_values_for_option_name && !$self->sub_commands) {
-            my $handler = Getopt::Complete::files->($command,$current,$previous,$all);
-            @possibilities = @$handler;
-        }
         else {
             # no possibilities
+            # print STDERR "recvd: " . join(',',@_) . "\n";
             @possibilities = ();
         }
 
@@ -490,7 +479,7 @@ Getopt::Complete::Args - a set of option/value pairs
 
 =head1 VERSION
 
-This document describes Getopt::Complete::Args 0.23.
+This document describes Getopt::Complete::Args v0.10.
 
 =head1 SYNOPSIS
 
@@ -590,7 +579,7 @@ L<Getopt::Complete>, L<Getopt::Complete::Options>, L<Getopt::Complete::Compgen>
 
 =head1 COPYRIGHT
 
-Copyright 2010 Scott Smith and Washington University School of Medicine
+Copyright 20.10 Scott Smith and Washington University School of Medicine
 
 =head1 AUTHORS
 
