@@ -3,7 +3,8 @@ package Getopt::Complete::Compgen;
 use strict;
 use warnings;
 
-our $VERSION = $Getopt::Complete::VERSION;
+use version;
+our $VERSION = qv('0.10');
 
 # Support the shell-builtin completions.
 # Some hackery seems to be required to replicate regular file completion.
@@ -31,16 +32,7 @@ for my $subname (qw/
         my @f =  grep { $_ !~/^\s+$/ } `bash -c "compgen -$option -- '$value'"`; 
         chomp @f;
         if ($option eq 'f' or $option eq 'd') {
-            # bash is fine with ~/ paths but perl is not, need to translate
-            my $home_dir = (getpwuid($<))[7];
-            for (my $i = 0; $i < @f; $i++) {
-                my $perl_path = $f[$i];
-                $perl_path =~ s/^~/$home_dir/;
-                if ( -d $perl_path ) {
-                    $f[$i] .= "/\t";
-                }
-            }
-
+            @f = map { -d $_ ? "$_/\t" : $_ } @f;
             my @not_shown = ($value);
             push @f, \@not_shown;
             push @not_shown, '-' if $Getopt::Complete::LONE_DASH_SUPPORT and $option eq 'f';
@@ -64,7 +56,7 @@ Getopt::Complete::Compgen - standard tab-completion callbacks
 
 =head1 VERSION
 
-This document describes Getopt::Complete::Compgen 0.23.
+This document describes Getopt::Complete::Compgen v0.10.
 
 =head1 SYNOPSIS
 
@@ -124,7 +116,7 @@ The manual page for bash details the bash built-in command "compgen", which this
 
 =head1 COPYRIGHT
 
-Copyright 2010 Scott Smith and Washington University School of Medicine
+Copyright 20.10 Scott Smith and Washington University School of Medicine
 
 =head1 AUTHORS
 
