@@ -3,11 +3,11 @@ package Getopt::Complete::Options;
 use strict;
 use warnings;
 
-our $VERSION = $Getopt::Complete::VERSION;
+use version;
+our $VERSION = qv('0.10');
 
 use IPC::Open2;
 use Data::Dumper;
-use Getopt::Complete::LazyOptions;
 
 sub new {
     my $class = shift;
@@ -104,16 +104,10 @@ sub _init {
         if (substr($name,0,1) eq '>') {
             # a "sub-command": make a sub-options tree, which may happen recursively
             my $word = substr($name,1);
-            if (ref($handler) eq 'ARRAY') {
-                $handler = Getopt::Complete::Options->new(@$handler);
-            }
-            elsif (ref($handler) eq 'CODE' or ref($handler) eq 'SCALAR') {
-                # be lazy about actually resolving this               
-                $handler = Getopt::Complete::LazyOptions->new($handler);
-            }
-            else {
-                die "expected arrayref or code for $name value!";
+            unless (ref($handler) eq 'ARRAY') {
+                die "expected arrayref for $name value!";
             }
+            $handler = Getopt::Complete::Options->new(@$handler);
             $handler->{command} = ($self->{command} || '') . " " . $word; 
             $completion_handlers->{$name} = $handler;
             push @{ $self->{sub_commands} }, $word;
@@ -157,12 +151,8 @@ sub handle_shell_completion {
             exit;
         }
         my $args = Getopt::Complete::Args->new(options => $self, argv => $other);
-        my @matches;
-        my @printable_matches;
-        unless ($args->errors) {
-            @matches = $args->resolve_possible_completions($command,$current,$previous);
-            @printable_matches = $args->translate_completions_for_shell_display($current, @matches);
-        }
+        my @matches = $args->resolve_possible_completions($command,$current,$previous);
+        my @printable_matches = $args->translate_completions_for_shell_display($current, @matches);
         print join("\n",@printable_matches),"\n";
         exit;
     }
@@ -180,14 +170,7 @@ sub _line_to_argv {
     my $result = join("",<$reader>);
     no strict; no warnings;
     my $array = eval $result;
-    my @array = @$array;
-
-    # We don't want to expand ~ for user experience and to be consistent with
-    # Bash's behavior for tab completion (as opposed to expansion of ARGV).
-    my $home_dir = (getpwuid($<))[7];
-    @array = map { $_ =~ s/^$home_dir/\~/; $_ } @array;
-
-    return @array;
+    return @$array;
 }
 
 sub parse_completion_request {
@@ -197,12 +180,11 @@ sub parse_completion_request {
     my $left = substr($comp_line,0,$comp_point);
     my @left = _line_to_argv($left);
 
-    # find options for last sub-command if it has a completion handler
-    # skipping first command but old code didn't but it also never seemed to trigger before
-    my @sub_cmds = @left[1..$#left];
-    while (@sub_cmds and my $delegate = $self->completion_handler('>' . $sub_cmds[0])) {
-        shift @sub_cmds;
-        $self = $delegate;
+    if (@left and my $delegate = $self->completion_handler('>' . $left[0])) {
+        # the first word matches a sub-command for this command
+        # delegate to the options object for that sub-command, which
+        # may happen recursively
+        return $delegate->parse_completion_request(@_);
     }
 
     my $right = substr($comp_line,$comp_point);
@@ -215,16 +197,15 @@ sub parse_completion_request {
  
     my $command = shift @left;
     my $current;
-    if (substr($left, -1) ne ' ' || substr($left, -2) eq '\ ') {
+    $left =~ s/\\ / /g;
+    if (@left and $left[-1] eq substr($left,-1*length($left[-1]))) {
         # we're at the end of the final word in the @left list, and are trying to complete it
         $current = pop @left;
     }
     else {
         $current = '';
     }
-    $left =~ s/\\ / /g;
-    my $previous = ( (@left and $left[-1] =~ /^-{1,2}/ and not $left[-1] =~ /^-{1,2}[\w\-]+\=/) ? (pop @left) : ()) ;
-    # TODO: this might be a good spot to make sure we don't complete a new sub-command
+    my $previous = ( (@left and $left[-1] =~ /^--/ and not $left[-1] =~ /^--[\w\-]+\=/) ? (pop @left) : ()) ;
     my @other_options = (@left,@right);
 
     # it's hard to spot the case in which the previous word is "boolean", and has no value specified
@@ -259,7 +240,6 @@ sub parse_completion_request {
     return ($command,$current,$previous,\@other_options, $quote);
 }
 
-1;
 
 =pod 
 
@@ -269,7 +249,7 @@ Getopt::Complete::Options - a command-line options specification
 
 =head1 VERSION
 
-This document describes Getopt::Complete 0.23
+This document describes Getopt::Complete v0.10.
 
 =head1 SYNOPSIS
 
@@ -317,7 +297,7 @@ L<Getopt::Complete>, L<Getopt::Complete::Args>, L<Getopt::Complete;:Compgen>
 
 =head1 COPYRIGHT
 
-Copyright 2010 Scott Smith and Washington University School of Medicine
+Copyright 20.10 Scott Smith and Washington University School of Medicine
 
 =head1 AUTHORS
 
